@@ -48,6 +48,7 @@ type MergeOptions struct {
 	IsDeleteBranchIndicated bool
 	CanDeleteLocalBranch    bool
 	MergeStrategyEmpty      bool
+	MatchHeadCommit         string
 }
 
 // ErrAlreadyInMergeQueue indicates that the pull request is already in a merge queue
@@ -175,6 +176,7 @@ func NewCmdMerge(f *cmdutil.Factory, runF func(*MergeOptions) error) *cobra.Comm
 	cmd.Flags().BoolVarP(&flagSquash, "squash", "s", false, "Squash the commits into one commit and merge it into the base branch")
 	cmd.Flags().BoolVar(&opts.AutoMergeEnable, "auto", false, "Automatically merge only after necessary requirements are met")
 	cmd.Flags().BoolVar(&opts.AutoMergeDisable, "disable-auto", false, "Disable auto-merge for this pull request")
+	cmd.Flags().StringVar(&opts.MatchHeadCommit, "match-head-commit", "", "Commit `SHA` that the pull request head must match to allow merge")
 	return cmd
 }
 
@@ -270,13 +272,14 @@ func (m *mergeContext) merge() error {
 	}
 
 	payload := mergePayload{
-		repo:          m.baseRepo,
-		pullRequestID: m.pr.ID,
-		method:        m.opts.MergeMethod,
-		auto:          m.autoMerge,
-		commitSubject: m.opts.Subject,
-		commitBody:    m.opts.Body,
-		setCommitBody: m.opts.BodySet,
+		repo:            m.baseRepo,
+		pullRequestID:   m.pr.ID,
+		method:          m.opts.MergeMethod,
+		auto:            m.autoMerge,
+		commitSubject:   m.opts.Subject,
+		commitBody:      m.opts.Body,
+		setCommitBody:   m.opts.BodySet,
+		expectedHeadOid: m.opts.MatchHeadCommit,
 	}
 
 	if m.shouldAddToMergeQueue() {
@@ -367,6 +370,7 @@ func (m *mergeContext) deleteLocalBranch() error {
 	if m.merged {
 		// prompt for delete
 		if m.opts.IO.CanPrompt() && !m.opts.IsDeleteBranchIndicated {
+			//nolint:staticcheck // SA1019: prompt.SurveyAskOne is deprecated: use Prompter
 			err := prompt.SurveyAskOne(&survey.Confirm{
 				Message: fmt.Sprintf("Pull request #%d was already merged. Delete the branch locally?", m.pr.Number),
 				Default: false,
@@ -472,7 +476,7 @@ func (m *mergeContext) infof(format string, args ...interface{}) error {
 func NewMergeContext(opts *MergeOptions) (*mergeContext, error) {
 	findOptions := shared.FindOptions{
 		Selector: opts.SelectorArg,
-		Fields:   []string{"id", "number", "state", "title", "lastCommit", "mergeStateStatus", "headRepositoryOwner", "headRefName", "baseRefName", "isInMergeQueue", "isMergeQueueEnabled"},
+		Fields:   []string{"id", "number", "state", "title", "lastCommit", "mergeStateStatus", "headRepositoryOwner", "headRefName", "baseRefName", "headRefOid", "isInMergeQueue", "isMergeQueueEnabled"},
 	}
 	pr, baseRepo, err := opts.Finder.Find(findOptions)
 	if err != nil {
@@ -568,6 +572,7 @@ func mergeMethodSurvey(baseRepo *api.Repository) (PullRequestMergeMethod, error)
 	}
 
 	var result int
+	//nolint:staticcheck // SA1019: prompt.SurveyAskOne is deprecated: use Prompter
 	err := prompt.SurveyAskOne(mergeQuestion, &result)
 	return mergeOpts[result].method, err
 }
@@ -586,6 +591,7 @@ func deleteBranchSurvey(opts *MergeOptions, crossRepoPR, localBranchExists bool)
 			Message: message,
 			Default: false,
 		}
+		//nolint:staticcheck // SA1019: prompt.SurveyAskOne is deprecated: use Prompter
 		err := prompt.SurveyAskOne(submit, &result)
 		return result, err
 	}
@@ -612,6 +618,7 @@ func confirmSurvey(allowEditMsg bool) (shared.Action, error) {
 		Message: "What's next?",
 		Options: options,
 	}
+	//nolint:staticcheck // SA1019: prompt.SurveyAskOne is deprecated: use Prompter
 	err := prompt.SurveyAskOne(submit, &result)
 	if err != nil {
 		return shared.CancelAction, fmt.Errorf("could not prompt: %w", err)
