@@ -7,10 +7,10 @@ import (
 	"time"
 
 	"github.com/cli/cli/v2/internal/browser"
+	"github.com/cli/cli/v2/internal/text"
 	"github.com/cli/cli/v2/pkg/cmdutil"
 	"github.com/cli/cli/v2/pkg/iostreams"
 	"github.com/cli/cli/v2/pkg/search"
-	"github.com/cli/cli/v2/pkg/text"
 	"github.com/cli/cli/v2/utils"
 )
 
@@ -31,6 +31,7 @@ type IssuesOptions struct {
 	Entity   EntityType
 	Exporter cmdutil.Exporter
 	IO       *iostreams.IOStreams
+	Now      time.Time
 	Query    search.Query
 	Searcher search.Searcher
 	WebMode  bool
@@ -54,7 +55,7 @@ func SearchIssues(opts *IssuesOptions) error {
 	if opts.WebMode {
 		url := opts.Searcher.URL(opts.Query)
 		if io.IsStdoutTTY() {
-			fmt.Fprintf(io.ErrOut, "Opening %s in your browser.\n", utils.DisplayURL(url))
+			fmt.Fprintf(io.ErrOut, "Opening %s in your browser.\n", text.DisplayURL(url))
 		}
 		return opts.Browser.Browse(url)
 	}
@@ -88,10 +89,13 @@ func SearchIssues(opts *IssuesOptions) error {
 		return cmdutil.NewNoResultsError(msg)
 	}
 
-	return displayIssueResults(io, opts.Entity, result)
+	return displayIssueResults(io, opts.Now, opts.Entity, result)
 }
 
-func displayIssueResults(io *iostreams.IOStreams, et EntityType, results search.IssuesResult) error {
+func displayIssueResults(io *iostreams.IOStreams, now time.Time, et EntityType, results search.IssuesResult) error {
+	if now.IsZero() {
+		now = time.Now()
+	}
 	cs := io.ColorScheme()
 	tp := utils.NewTablePrinter(io)
 	for _, issue := range results.Items {
@@ -112,17 +116,15 @@ func displayIssueResults(io *iostreams.IOStreams, et EntityType, results search.
 		if issue.IsPullRequest() {
 			tp.AddField(issueNum, nil, cs.ColorFromString(colorForPRState(issue.State)))
 		} else {
-			tp.AddField(issueNum, nil, cs.ColorFromString(colorForIssueState(issue.State)))
+			tp.AddField(issueNum, nil, cs.ColorFromString(colorForIssueState(issue.State, issue.StateReason)))
 		}
 		if !tp.IsTTY() {
 			tp.AddField(issue.State, nil, nil)
 		}
-		tp.AddField(text.ReplaceExcessiveWhitespace(issue.Title), nil, nil)
+		tp.AddField(text.RemoveExcessiveWhitespace(issue.Title), nil, nil)
 		tp.AddField(listIssueLabels(&issue, cs, tp.IsTTY()), nil, nil)
-		now := time.Now()
-		ago := now.Sub(issue.UpdatedAt)
 		if tp.IsTTY() {
-			tp.AddField(utils.FuzzyAgo(ago), nil, cs.Gray)
+			tp.AddField(text.FuzzyAgo(now, issue.UpdatedAt), nil, cs.Gray)
 		} else {
 			tp.AddField(issue.UpdatedAt.String(), nil, nil)
 		}
@@ -159,11 +161,14 @@ func listIssueLabels(issue *search.Issue, cs *iostreams.ColorScheme, colorize bo
 	return strings.Join(labelNames, ", ")
 }
 
-func colorForIssueState(state string) string {
+func colorForIssueState(state, reason string) string {
 	switch state {
 	case "open":
 		return "green"
 	case "closed":
+		if reason == "not_planned" {
+			return "gray"
+		}
 		return "magenta"
 	default:
 		return ""
