@@ -11,6 +11,7 @@ import (
 	"github.com/cli/cli/v2/api"
 	"github.com/cli/cli/v2/internal/browser"
 	"github.com/cli/cli/v2/internal/ghrepo"
+	"github.com/cli/cli/v2/internal/text"
 	runShared "github.com/cli/cli/v2/pkg/cmd/run/shared"
 	"github.com/cli/cli/v2/pkg/cmd/workflow/shared"
 	"github.com/cli/cli/v2/pkg/cmdutil"
@@ -123,7 +124,7 @@ func runView(opts *ViewOptions) error {
 			address = ghrepo.GenerateRepoURL(repo, "actions/workflows/%s", url.QueryEscape(workflow.Base()))
 		}
 		if opts.IO.IsStdoutTTY() {
-			fmt.Fprintf(opts.IO.Out, "Opening %s in your browser.\n", utils.DisplayURL(address))
+			fmt.Fprintf(opts.IO.Out, "Opening %s in your browser.\n", text.DisplayURL(address))
 		}
 		return opts.Browser.Browse(address)
 	}
@@ -194,7 +195,10 @@ func viewWorkflowContent(opts *ViewOptions, client *api.Client, repo ghrepo.Inte
 }
 
 func viewWorkflowInfo(opts *ViewOptions, client *api.Client, repo ghrepo.Interface, workflow *shared.Workflow) error {
-	wr, err := getWorkflowRuns(client, repo, workflow)
+	wr, err := runShared.GetRuns(client, repo, &runShared.FilterOptions{
+		WorkflowID:   workflow.ID,
+		WorkflowName: workflow.Name,
+	}, 5)
 	if err != nil {
 		return fmt.Errorf("failed to get runs: %w", err)
 	}
@@ -209,13 +213,13 @@ func viewWorkflowInfo(opts *ViewOptions, client *api.Client, repo ghrepo.Interfa
 	fmt.Fprintf(out, "ID: %s\n\n", cs.Cyanf("%d", workflow.ID))
 
 	// Runs
-	fmt.Fprintf(out, "Total runs %d\n", wr.Total)
+	fmt.Fprintf(out, "Total runs %d\n", wr.TotalCount)
 
-	if wr.Total != 0 {
+	if wr.TotalCount != 0 {
 		fmt.Fprintln(out, "Recent runs")
 	}
 
-	for _, run := range wr.Runs {
+	for _, run := range wr.WorkflowRuns {
 		if opts.Raw {
 			tp.AddField(string(run.Status), nil, nil)
 			tp.AddField(string(run.Conclusion), nil, nil)
@@ -224,9 +228,9 @@ func viewWorkflowInfo(opts *ViewOptions, client *api.Client, repo ghrepo.Interfa
 			tp.AddField(symbol, nil, symbolColor)
 		}
 
-		tp.AddField(run.CommitMsg(), nil, cs.Bold)
+		tp.AddField(run.Title(), nil, cs.Bold)
 
-		tp.AddField(run.Name, nil, nil)
+		tp.AddField(run.WorkflowName(), nil, nil)
 		tp.AddField(run.HeadBranch, nil, cs.Bold)
 		tp.AddField(string(run.Event), nil, nil)
 
@@ -247,7 +251,7 @@ func viewWorkflowInfo(opts *ViewOptions, client *api.Client, repo ghrepo.Interfa
 	fmt.Fprintln(out)
 
 	// Footer
-	if wr.Total != 0 {
+	if wr.TotalCount != 0 {
 		fmt.Fprintf(out, "To see more runs for this workflow, try: gh run list --workflow %s\n", filename)
 	}
 	fmt.Fprintf(out, "To see the YAML for this workflow, try: gh workflow view %s --yaml\n", filename)
